#include "FirebaseMLKitImpl.h"


FirebaseMLKitImpl::FirebaseMLKitImpl()
{
}

FirebaseMLKitImpl::~FirebaseMLKitImpl()
{
}

void FirebaseMLKitImpl::Init(int mode)
{
}

void FirebaseMLKitImpl::Release()
{
}

void FirebaseMLKitImpl::Preview()
{
}

float FirebaseMLKitImpl::GetHeadEulerAngleY()
{
	return 0;
}

float FirebaseMLKitImpl::GetHeadEulerAngleZ()
{
	return 0;
}

float* FirebaseMLKitImpl::GetContours(int& size)
{
	return {};
}